@@ -391,6 +391,18 @@ class ExternalResourceTests(TestCase):
         self.assertEqual('hello', self.loader.get_bytes('bambi', 'bim:///gooshy/gooshy/gander'))
         self.assertEqual('///gooshy/gooshy/bambi', mock_func.call_args[0][0])
 
+    @patch('__builtin__.open')
+    def test_trivial_catalogue(self, mock_open):
+        mock_open.return_value = StringIO('fish')
+
+        self.loader.add_local_knowledge('http://example.org/bam/', '/banjo/ukelele')
+        spec = self.loader.maybe_get_spec('http://example.org/bam/gosh/wow.tprx')
+        self.assertEqual('fish', spec)
+        self.assertTrue(mock_open.called)
+        self.assertEqual('/banjo/ukelele/gosh/wow.tprx', mock_open.call_args[0][0])
+        self.assertTrue(mock_open.call_args[0][1].startswith('r'))
+
+
 
 class ResolveUrlTests(unittest.TestCase):
     # I ended up creating my own generic URL resolver, because
