@@ -162,10 +162,14 @@ class Loader(object):
         self._specs = {}
         self._things = {}
         self._schemes = {}
+        self._locals = []
 
     def add_scheme(self, prefix, func):
         self._schemes[prefix] = func
 
+    def add_local_knowledge(self, prefix, dir_path):
+        self._locals.append((prefix, dir_path))
+
     def get_url(self, spec, base=None):
         """Given a spec, return URL for the resource it specifes.
 
@@ -242,6 +246,13 @@ class Loader(object):
                 meta is a dict containing 'content-type'
                 strm is a file-like object
         """
+        # Knowledge that some HTTP URLs are available locally:
+        for prefix, dir_path in self._locals:
+            if url.startswith(prefix):
+                file_path = os.path.join(dir_path, url[len(prefix):])
+                url = url_from_file_path(file_path)
+                break
+
         if url.startswith('file://'):
             file_path = url[7:]
 
